contexttools.KeySignatureMark
=============================

.. abjad-lineage:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark

.. autoclass:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.name
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.target_context
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.mode
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.tonic
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.detach
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__delattr__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__ge__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__gt__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__le__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__lt__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__repr__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__str__
   :noindex:
